
# FleetingViews intents to facilitate Flet views usage.


FleetingViews is a utility class designed for managing views within Flet applications. It simplifies the process of creating, navigating, and customizing views, similar to how web frameworks manage routes. FleetingViews allows you to define views with specific configurations, keep track of navigation history, and dynamically update view content.

## Installation
```
pip install fleeting-views
```

## Upgradation
```
pip install fleeting-views --upgrade
```


#### [Repository](https://arellanobrunoc.github.io/FleetingViews/)


## Author

<b>Name :</b> Bruno Arellano<br>
<b>Email :</b> arellanobruno@hotmail.com<br>
<b>Country :</b> COLOMBIA<br>

